# gopal_rotipy

A Python package to calculate the Rate of Total Electron Content Index (ROTI) from GPS TEC data, aiding ionospheric studies and space weather analysis. This package is developed by Tesfay-Tesfu (PhD student), under the supervion of Gopalswamy(NASA-GSF, USA) and Virginia (UNIVAP, Brazil), thanks to their guidance and an incredible support. 
Contact: tesfayphysics@gmail.com
Github: https://github.com/Tesfay-Tesfu

## Features

- Computes ROT (Rate of TEC) and ROTI (Rate of TEC Index) from TEC data.
- Supports input from Cmn and other common data formats.
- Provides easy-to-use functions for preprocessing and analysis.

## Installation

Pre-requesite libraries are listed here below:

-pip install numpy
-pip install pandas
-pip install os
# Check The following importing libraries
"""
import os
import glob
import pandas as pd
import numpy as np
import tkinter as tk
from tkinter import filedialog
from tkinter import simpledialog
import ipywidgets as widgets
from IPython.display import display
"""
### Install the package directly from PyPI:
```bash
pip install gopal_rotipy


